#
# spec file for package libmodulemd
#
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global majorversion 2
%global minorversion 8
%global patchversion 3
%global majorminorversion %{majorversion}.%{minorversion}
%global nsversion %{majorversion}.0

%global libmodulemd_version %{majorminorversion}%{?patchversion:.%{patchversion}}

%global libname %{name}%{majorversion}
%global devname %{name}-devel
%global girname typelib-1_0-Modulemd-%{majorversion}_0


Name:           libmodulemd
Version:        %{libmodulemd_version}
Release:        lp152.7.5
Summary:        Module metadata manipulation library
Group:          System/Packages
License:        MIT
URL:            https://github.com/fedora-modularity/libmodulemd
Source0:        %{url}/releases/download/%{name}-%{libmodulemd_version}/modulemd-%{libmodulemd_version}.tar.xz

BuildRequires:  meson >= 0.47.0
BuildRequires:  gcc
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  python3-gobject
BuildRequires:  rpm-devel
BuildRequires:  file-devel
# For tests
BuildRequires:  gcc-c++

%description
C Library for manipulating module metadata files.


%package -n modulemd-validator
Summary:        Tool for validating modulemd data
Group:          System/Packages
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}

%description -n modulemd-validator
The modulemd-validator tool provides the facility for verifying
constructed modulemd data is correct and usable.

%package -n python3-%{name}
Summary:        Python 3 bindings for %{name}
Group:          Development/Libraries/Python
Requires:       %{girname}%{?_isa} = %{libmodulemd_version}-%{release}
Requires:       python3-gobject
Requires:       python3-six

%description -n python3-%{name}
This package provides the Python 3 bindings for %{name}.

%package -n %{libname}
Summary:        Main library for %{name}
Group:          System/Libraries

%description -n %{libname}
This package provides the main library for applications
that use %{name}.

%package -n %{girname}
Summary:        GObject Introspection interface description for %{name}
Group:          System/Libraries
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}

%description -n %{girname}
This package provides the GObject Introspection typelib interface
for applications to use %{name}.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{libmodulemd_version}-%{release}
Requires:       %{girname}%{?_isa} = %{libmodulemd_version}-%{release}

%description -n %{devname}
This package provides files for developing applications to use %{name}.

%prep
%autosetup -p1 -n modulemd-%{libmodulemd_version}

%build
%meson -Ddeveloper_build=false \
       -Dwith_py3_overrides=true -Dwith_py2_overrides=false

%meson_build

%check
export LC_CTYPE=C.utf8
# Don't run tests on ARM and RISC-V for now. There are problems
# with performance on the builders and often these time out.
%ifnarch %{arm} aarch64 riscv64
%meson_test
%endif

%install
%meson_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n modulemd-validator
%license COPYING
%doc README.md
%{_bindir}/modulemd-validator

%files -n python3-%{name}
%{python3_sitearch}/gi/overrides/Modulemd.py

%files -n %{libname}
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.%{majorversion}*

%files -n %{girname}
%{_libdir}/girepository-1.0/Modulemd-%{nsversion}.typelib

%files -n %{devname}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/modulemd-%{nsversion}.pc
%{_includedir}/modulemd-%{nsversion}/
%{_datadir}/gir-1.0/Modulemd-%{nsversion}.gir
%{_datadir}/gtk-doc/html/modulemd-%{nsversion}/

%changelog
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 2.8.3
  + Detect GDate autoptr when available to fix build with glib2 >= 2.63.3
  + Correct typo in MODULEMD_REPLACE_SET()
  + Fix modulemd_buildopts_copy() to make a deep copy of the rpm whitelist
  + Add support for new ModulemdBuildopts arches attribute
* Sun Dec  1 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 2.8.2
  + modulemd v1 has been split out into is own tarball
  + Add ModuleIndexMerger.resolve_ext()
  + Fix transfer type for Module.search_streams()
  + Correct typo in ModulemdModuleStream.arch property nickname
  + Add gtk-doc descriptions for ModulemdModuleStream object properties
  + Fix modulemd_yaml_parse_bool() comparisons so return value is correct
  + Make ModulemdErrorEnum and ModulemdYamlErrorEnum into public enums
  + Move modulemd_module_stream_v2_replace_*() method definitions
    to correct header file and add documentation
  + Refactor stream copy/upgrade helper macros
  + Add Modulemd.Module.get_translation()
  + Add ModuleIndex.update_from_defaults_directory()
  + Modulemd.ModuleIndex.update_from_file() now supports reading files
    compressed with gzip, bzip2 or xz
- libmodulemd1 has been split into its own package
* Fri May 24 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 2.5.0 (v2) and 1.8.11 (v1)
  + Ensure that XMD is always emitted in the same order
  + Add .clear_*() functions for all .add_*() functions
  + Add ModuleStream.equals()
  + Add ModuleIndex.get_default_streams()
  + Add ModuleStreamV2.clear_dependencies() and .remove_dependencies()
  + Fix bugs and memory issues with the XMD python bindings
  + Assorted documentation enhancements
* Fri May 10 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 2.3.1 (v2) and 1.8.8 (v1)
  + Make Modulemd.Component.set_*() functions accept NULL (gh#fedora-modularity/libmodulemd#279)
  + Fix segmentation fault in XMD code due to improper memory management (gh#fedora-modularity/libmodulemd#274)
  + Fix assorted documentation issues
- Disable executing test suite on ARM and RISC-V due to performance issues with builders
* Sun Apr 28 2019 Neal Gompa <ngompa13@gmail.com>
- Add missing dependency on six module for Python 3 bindings subpackage
* Tue Apr 23 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 2.3.0 (v2) and 1.8.7 (v1)
  + Add ModuleIndex.update_from_custom()
  + Add ModuleIndex.dump_to_custom()
  + Add Component.equals()
  + Add Module.remove_streams_by_NSVCA()
  + Fix bug with emitting lists of scalars in XMD
  + Fix bug with deduplication in the ModuleIndexMerger
  + Fix serious memory leak
- Drop patch included in upstream release
  * 0001-Only-require-python2-if-installing-overrides.patch
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 2.2.2 (v2) and 1.8.5 (v1)
  + Fix documentation for ModuleStream.depends_on_stream()
  + Update APIs to handling full NSVCA of modules
  + Add new APIs for handling full NSVCA of modules
  + Add 'buildonly' option for components
  + Add 'buildafter' component
  + Add config option for python overrides
- Drop patches included in upstream release
  * 0001-V2-Add-missing-include-for-string.h-to-modulemd-util.patch
  * 0002-Tests-Use-bin-bash-for-interpreter-shebangs-for-shel.patch
- Add patch backported from upstream to avoid Python 2 dependency
  * 0001-Only-require-python2-if-installing-overrides.patch
* Tue Feb  5 2019 Neal Gompa <ngompa13@gmail.com>
- Add patches backported from upstream to fix build on openSUSE
  * 0001-V2-Add-missing-include-for-string.h-to-modulemd-util.patch
  * 0002-Tests-Use-bin-bash-for-interpreter-shebangs-for-shel.patch
- Run tests during package builds
* Sun Feb  3 2019 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia package
